@@ -4,7 +4,7 @@ from nonebot import on_regex
 from nonebot.adapters import Bot, Event
 
 analysis_bili = on_regex(
-    r"(b23.tv)|(bili(22|23|33|2233).cn)|((live|t).bilibili.com/(blanc/|h5/)?(\d+))|(bilibili.com/(video|read|bangumi))|(^(av|cv)(\d+))|((^|bvid=)BV([a-zA-Z0-9]{10})+)|(\[\[QQ小程序\]哔哩哔哩\])|(QQ小程序&amp;#93;哔哩哔哩)|(QQ小程序&#93;哔哩哔哩)",
+    r"(b23.tv)|(bili(22|23|33|2233).cn)|((live|t|m).bilibili.com/(blanc/|h5/)?(\d+))|(bilibili.com/(video|read|bangumi))|(^(av|cv)(\d+))|((^|bvid=)BV([a-zA-Z0-9]{10})+)|(\[\[QQ小程序\]哔哩哔哩\])|(QQ小程序&amp;#93;哔哩哔哩)|(QQ小程序&#93;哔哩哔哩)",
     flags=re.I,
 )
 
