@@ -2,6 +2,7 @@ import re
 import aiohttp
 import time
 import urllib.parse
+import json
 
 analysis_stat = {}  # analysis_stat: video_url(vurl)
 
@@ -17,13 +18,13 @@ async def bili_keyword(group_id, text):
             i = 0
             while i < len(desc):
                 title_dict = "{" + desc[i] + "}"
-                title = eval(title_dict)
+                title = json.loads(title_dict)
                 i += 1
                 if title["desc"] == "哔哩哔哩":
                     continue
                 vurl = await search_bili_by_title(title["desc"])
                 if vurl:
-                    url = await extract(vurl)
+                    url, page = await extract(vurl)
                     break
 
         # 获取视频详细信息
@@ -76,7 +77,10 @@ async def extract(text: str):
         cvid = re.compile(r"(cv|/read/(mobile|native)(/|\?id=))(\d+)", re.I).search(
             text
         )
-        dynamic_id = re.compile(r"t.bilibili.com/(\d+)", re.I).search(text)
+        dynamic_id_type2 = re.compile(
+            r"(t|m).bilibili.com/(\d+)\?(.*?)(&|&amp;)type=2", re.I
+        ).search(text)
+        dynamic_id = re.compile(r"(t|m).bilibili.com/(\d+)", re.I).search(text)
         if bvid:
             url = f"https://api.bilibili.com/x/web-interface/view?bvid={bvid[0]}"
         elif aid:
@@ -93,8 +97,10 @@ async def extract(text: str):
             url = f"https://api.live.bilibili.com/xlive/web-room/v1/index/getInfoByRoom?room_id={room_id[2]}"
         elif cvid:
             url = f"https://api.bilibili.com/x/article/viewinfo?id={cvid[4]}&mobi_app=pc&from=web"
+        elif dynamic_id_type2:
+            url = f"https://api.vc.bilibili.com/dynamic_svr/v1/dynamic_svr/get_dynamic_detail?rid={dynamic_id_type2[2]}&type=2"
         elif dynamic_id:
-            url = f"https://api.vc.bilibili.com/dynamic_svr/v1/dynamic_svr/get_dynamic_detail?dynamic_id={dynamic_id[1]}"
+            url = f"https://api.vc.bilibili.com/dynamic_svr/v1/dynamic_svr/get_dynamic_detail?dynamic_id={dynamic_id[2]}"
         return url, page
     except:
         return None, None
@@ -296,4 +302,4 @@ async def dynamic_detail(url):
         return msg, vurl
     except Exception as e:
         msg = "动态解析出错--Error: {}".format(type(e))
-        return msg, None
\ No newline at end of file
+        return msg, None
